==> diogenes_0.9.14.orig.tar.gz: diogenes-0.9.14/include/admin/edit.php <==
<?php
require_once 'diogenes.common.inc.php';
require_once 'diogenes.admin.inc.php';

if (!isset($_REQUEST['dir']) && !isset($_REQUEST['file']))
  exit;

// retrieve directory & file info
$dir = $_REQUEST["dir"];
$file = $_REQUEST["file"];
$page = new DiogenesAdmin($dir);

$res = $globals->db->query("select location from {$page->table_page} where PID='$dir'");
if (!list($dirloc) = mysql_fetch_row($res))
  $page->kill(__("Directory not found"));

// rcs handle
$rcs = $page->getRcs();

// file location & url
$mydir = $page->spool->spoolPath($dir);
$myfile = $page->spool->spoolPath($dir,$file);

// process requested action
$action = isset($_REQUEST["action"]) ? $_REQUEST["action"] : "";
switch($action)
{
case "update":
  // update the current file with form contents
  if (isset($_REQUEST['file_content'])) {
    $page->info(__("Commiting changes to file") . " $file");
    $message = empty($_REQUEST['message']) ? "updated using editor" : stripslashes($_REQUEST['message']);
    $rcs->commit($dir,$file,stripslashes($_REQUEST['file_content']),$message);
  }

  break;
}

$rev = array_shift($rcs->logParse($dir,$file));

$page->assign('greeting', __("File editor")." - $dirloc/$file - {$rev['rev']}");
$page->assign('post',$page->script_self());
$page->assign('dir',$dir);
$page->assign('file',$file);
$page->assign('source',__("File source"));
$page->assign('msg_log',__("log message"));
$page->assign('file_content',htmlspecialchars(file_get_contents($myfile), ENT_NOQUOTES));
$page->assign('submit',__("Submit"));
$page->toolbar(__("Page"), array (
  array( __("pages catalog"), "pages"),
  array( __("page properties"), "pages?PID=$dir" ),
  array( __("view page"), $page->urlSite($dirloc ? "$dirloc/" : "")),
  array( __("browse files"), "files?dir=$dir" )
));
$page->toolbar(__("File"), array (
  array( __("raw editor") ),
  array( __("HTML editor"), "ekit?dir=$dir&amp;file=$file" ),
  array( __("file revisions"), "files?action=revs&amp;dir=$dir&amp;target=$file" )
));
$page->display('admin-edit.tpl');
?>

==> diogenes_0.9.16.orig.tar.gz: diogenes-0.9.16/include/admin/edit.php <==
<?php
require_once 'diogenes.common.inc.php';
require_once 'diogenes.admin.inc.php';

if (!isset($_REQUEST['dir']) && !isset($_REQUEST['file']))
  exit;

// retrieve directory & file info
$dir = $_REQUEST["dir"];
$file = $_REQUEST["file"];
$page = new DiogenesAdmin($dir);

$res = $globals->db->query("select location from {$page->table_page} where PID='$dir'");
if (!list($dirloc) = mysql_fetch_row($res))
  $page->kill(__("Directory not found"));

// rcs handle
$rcs = $page->getRcs();

// file location & url
$mydir = $page->spool->spoolPath($dir);
$myfile = $page->spool->spoolPath($dir,$file);

// process requested action
$action = isset($_REQUEST["action"]) ? $_REQUEST["action"] : "";
switch($action)
{
case "update":
  // update the current file with form contents
  if (isset($_REQUEST['file_content'])) {
    $page->info(__("Commiting changes to file") . " $file");
    $message = empty($_REQUEST['message']) ? "updated using editor" : stripslashes($_REQUEST['message']);
    $rcs->commit($dir,$file,stripslashes($_REQUEST['file_content']),$message);
  }

  break;
}

$rev = array_shift($rcs->logParse($dir,$file));

$page->assign('greeting', __("File editor")." - $dirloc/$file - {$rev['rev']}");
$page->assign('post',$page->script_self());
$page->assign('dir',$dir);
$page->assign('file',$file);
$page->assign('source',__("File source"));
$page->assign('msg_log',__("log message"));
$page->assign('file_content',htmlspecialchars(file_get_contents($myfile), ENT_NOQUOTES));
$page->assign('submit',__("Submit"));
$page->toolbar(__("Page"), array (
  array( __("pages catalog"), "pages"),
  array( __("page properties"), "pages?PID=$dir" ),
  array( __("view page"), $page->urlSite($dirloc ? "$dirloc/" : "")),
  array( __("browse files"), "files?dir=$dir" )
));
$page->toolbar(__("File"), array (
  array( __("raw editor") ),
  array( __("HTML editor"), "compose?dir=$dir&amp;file=$file" ),
  array( __("file revisions"), "files?action=revs&amp;dir=$dir&amp;target=$file" )
));
$page->display('admin-edit.tpl');
?>
